==> pulsar-functions-runtime-2.7.5-sources.jar: org/apache/pulsar/functions/auth/FunctionAuthData.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.functions.auth;

import lombok.Builder;
import lombok.Data;

@Data
@Builder
/**
 * A wrapper for authentication data for functions
 */
public class FunctionAuthData {
    /**
     * function authentication related data that the function authentication provider
     * needs to cache/distribute to all workers support function authentication.
     * Depending on the function authentication provider implementation, this can be the actual auth credentials
     * or a pointer to the auth credentials that this function should use
     */
    private byte[] data;
    /**
     * classname of the function auth provicer this data is relevant to
     */
    private String provider;
}

==> pulsar-functions-runtime-2.10.0-rc-202204012205-sources.jar: org/apache/pulsar/functions/auth/FunctionAuthData.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.functions.auth;

import lombok.Builder;
import lombok.Data;

@Data
@Builder
/**
 * A wrapper for authentication data for functions
 */
public class FunctionAuthData {
    /**
     * function authentication related data that the function authentication provider
     * needs to cache/distribute to all workers support function authentication.
     * Depending on the function authentication provider implementation, this can be the actual auth credentials
     * or a pointer to the auth credentials that this function should use
     */
    private byte[] data;
    /**
     * classname of the function auth provicer this data is relevant to.
     */
    private String provider;
}
